@@ -15,9 +15,10 @@ with
     'WebService::DigitalOcean::Role::DropletActions',
     'WebService::DigitalOcean::Role::Keys',
     'WebService::DigitalOcean::Role::Regions',
-    'WebService::DigitalOcean::Role::Sizes';
+    'WebService::DigitalOcean::Role::Sizes',
+    'WebService::DigitalOcean::Role::Images';
 
-our $VERSION = '0.023'; # VERSION
+our $VERSION = '0.024'; # VERSION
 
 has api_base_url => (
     is      => 'ro',
@@ -45,7 +46,7 @@ WebService::DigitalOcean - Access the DigitalOcean RESTful API (v2)
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -159,7 +160,7 @@ The IP address the domain will point to.
 
 Creates a new top level domain.
 
-More info: L<< https://developers.digitalocean.com/#create-a-new-domain >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#create-a-new-domain >>.
 
 =head2 domain_delete
 
@@ -177,7 +178,7 @@ The domain name.
 
 Deletes the specified domain.
 
-More info: L<< https://developers.digitalocean.com/#delete-a-domain >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#delete-a-domain >>.
 
 =head2 domain_get
 
@@ -195,7 +196,7 @@ The domain name.
 
 Retrieves the specified domain.
 
-More info: L<< https://developers.digitalocean.com/#retrieve-an-existing-domain >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#retrieve-an-existing-domain >>.
 
 =head2 domain_list
 
@@ -207,7 +208,7 @@ More info: L<< https://developers.digitalocean.com/#retrieve-an-existing-domain
 
 Lists all domains for this account.
 
-More info: L<< https://developers.digitalocean.com/#list-all-domains >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#list-all-domains >>.
 
 =head2 domain_record_create
 
@@ -256,7 +257,7 @@ The weight, for SRV records.
 
 Creates a new record for a domain.
 
-More info: L<< https://developers.digitalocean.com/#create-a-new-domain-record >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#create-a-new-domain-record >>.
 
 =head2 domain_record_delete
 
@@ -281,7 +282,7 @@ The id of the record.
 
 Deletes the specified record.
 
-More info: L<< https://developers.digitalocean.com/#delete-a-domain-record >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#delete-a-domain-record >>.
 
 =head2 domain_record_get
 
@@ -308,7 +309,7 @@ The id of the record.
 
 Retrieves details about a particular record, identified by id.
 
-More info: L<< https://developers.digitalocean.com/#retrieve-an-existing-domain-record >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#retrieve-an-existing-domain-record >>.
 
 =head2 domain_record_list
 
@@ -330,7 +331,7 @@ The domain to which the records belong.
 
 Retrieves all the records for a particular domain.
 
-More info: L<< https://developers.digitalocean.com/#list-all-domain-records >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#list-all-domain-records >>.
 
 =head2 droplet_create
 
@@ -371,7 +372,7 @@ B<Arguments:>
 
 Creates a new droplet.
 
-More info: L<< https://developers.digitalocean.com/#create-a-new-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#create-a-new-droplet >>.
 
 =head2 droplet_delete
 
@@ -387,7 +388,7 @@ B<Arguments:>
 
 Deletes the specified droplet.
 
-More info: L<< https://developers.digitalocean.com/#delete-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#delete-a-droplet >>.
 
 =head2 droplet_get
 
@@ -403,7 +404,7 @@ B<Arguments:>
 
 Retrieves the specified droplet.
 
-More info: L<< https://developers.digitalocean.com/#retrieve-an-existing-droplet-by-id >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#retrieve-an-existing-droplet-by-id >>.
 
 =head2 droplet_list
 
@@ -415,12 +416,13 @@ More info: L<< https://developers.digitalocean.com/#retrieve-an-existing-droplet
 
 Lists all droplets for this account.
 
-More info: L<< https://developers.digitalocean.com/#list-all-droplets >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#list-all-droplets >>.
 
 =head2 droplet_resize
 
     $do->droplet_resize({
         droplet => 123456,
+        disk    => 1,
         size    => '1gb',
     });
 
@@ -430,13 +432,15 @@ B<Arguments:>
 
 =item C<Int> $args{droplet}
 
+=item C<Bool> $args{disk}
+
 =item C<Str> $args{size}
 
 =back
 
 Resizes a droplet.
 
-More info: L<< https://developers.digitalocean.com/#resize-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#resize-a-droplet >>.
 
 =head2 droplet_change_kernel
 
@@ -457,7 +461,7 @@ B<Arguments:>
 
 Changes the kernel of a droplet.
 
-More info: L<< https://developers.digitalocean.com/#change-the-kernel >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#change-the-kernel >>.
 
 =head2 droplet_rebuild
 
@@ -478,7 +482,7 @@ B<Arguments:>
 
 Rebuilds a droplet.
 
-More info: L<< https://developers.digitalocean.com/#rebuild-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#rebuild-a-droplet >>.
 
 =head2 droplet_restore
 
@@ -499,7 +503,7 @@ B<Arguments:>
 
 Restores a droplet to an image backup.
 
-More info: L<< https://developers.digitalocean.com/#restore-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#restore-a-droplet >>.
 
 =head2 droplet_rename
 
@@ -520,7 +524,7 @@ B<Arguments:>
 
 Renames a droplet, thus setting the reverse DNS.
 
-More info: L<< https://developers.digitalocean.com/#rename-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#rename-a-droplet >>.
 
 =head2 droplet_snapshot
 
@@ -541,7 +545,7 @@ B<Arguments:>
 
 Saves a snapshopt of the droplet.
 
-More info: L<< https://developers.digitalocean.com/#rebuild-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#rebuild-a-droplet >>.
 
 =head2 droplet_reboot
 
@@ -557,7 +561,7 @@ B<Arguments:>
 
 Reboots droplet.
 
-More info: L<< https://developers.digitalocean.com/#reboot-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#reboot-a-droplet >>.
 
 =head2 droplet_power_cycle
 
@@ -573,7 +577,7 @@ B<Arguments:>
 
 Power cycles droplet.
 
-More info: L<< https://developers.digitalocean.com/#power-cycle-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#power-cycle-a-droplet >>.
 
 =head2 droplet_power_on
 
@@ -589,7 +593,7 @@ B<Arguments:>
 
 Powers on droplet.
 
-More info: L<< https://developers.digitalocean.com/#power-on-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#power-on-a-droplet >>.
 
 =head2 droplet_power_off
 
@@ -605,7 +609,7 @@ B<Arguments:>
 
 Powers off droplet.
 
-More info: L<< https://developers.digitalocean.com/#power-off-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#power-off-a-droplet >>.
 
 =head2 droplet_password_reset
 
@@ -621,7 +625,7 @@ B<Arguments:>
 
 Resets the root password of the droplet.
 
-More info: L<< https://developers.digitalocean.com/#password-reset-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#password-reset-a-droplet >>.
 
 =head2 droplet_shutdown
 
@@ -637,7 +641,7 @@ B<Arguments:>
 
 Shuts down a droplet
 
-More info: L<< https://developers.digitalocean.com/#shutdown-a-droplet >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#shutdown-a-droplet >>.
 
 =head2 droplet_enable_ipv6
 
@@ -653,7 +657,7 @@ B<Arguments:>
 
 Enables IPv6 in a droplet.
 
-More info: L<< https://developers.digitalocean.com/#enable-ipv6 >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#enable-ipv6 >>.
 
 =head2 droplet_enable_private_networking
 
@@ -669,7 +673,7 @@ B<Arguments:>
 
 Enables private networking for a droplet.
 
-More info: L<< https://developers.digitalocean.com/#enable-private-networking >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#enable-private-networking >>.
 
 =head2 droplet_disable_backups
 
@@ -685,7 +689,7 @@ B<Arguments:>
 
 Disables backups for the droplet.
 
-More info: L<< https://developers.digitalocean.com/#disable-backups >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#disable-backups >>.
 
 =head2 droplet_action_get
 
@@ -706,7 +710,7 @@ B<Arguments:>
 
 Retrieve details from a specific action.
 
-More info: L<< https://developers.digitalocean.com/#retrieve-a-droplet-action >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#retrieve-a-droplet-action >>.
 
 =head2 key_create
 
@@ -727,7 +731,7 @@ B<Arguments:>
 
 Creates a new ssh key for this account.
 
-More info: L<< https://developers.digitalocean.com/#create-a-new-key >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#create-a-new-key >>.
 
 =head2 key_delete
 
@@ -745,7 +749,7 @@ B<Arguments:>
 
 Deletes the specified ssh key.
 
-More info: L<< https://developers.digitalocean.com/#destroy-a-key >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#destroy-a-key >>.
 
 =head2 key_get
 
@@ -763,13 +767,13 @@ B<Arguments:>
 
 Retrieves details about a particular ssh key, identified by id or fingerprint (pick one).
 
-More info: L<< https://developers.digitalocean.com/#retrieve-an-existing-key >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#retrieve-an-existing-key >>.
 
 =head2 key_list
 
 Retrieves all the keys for this account.
 
-More info: L<< https://developers.digitalocean.com/#list-all-keys >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#list-all-keys >>.
 
 =head2 region_list
 
@@ -783,7 +787,7 @@ More info: L<< https://developers.digitalocean.com/#list-all-keys >>.
 
 Retrieves all the regions available in Digital Ocean.
 
-More info: L<< https://developers.digitalocean.com/#list-all-regions >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#list-all-regions >>.
 
 =head2 size_list
 
@@ -795,7 +799,19 @@ Retrieves all the sizes available in Digital Ocean.
         say "Size $s->{slug} costs $s->{price_hourly} per hour.";
     }
 
-More info: L<< https://developers.digitalocean.com/#list-all-sizes >>.
+More info: L<< https://developers.digitalocean.com/documentation/v2/#list-all-sizes >>.
+
+=head2 image_list
+
+Retrieves all the images available in Digital Ocean.
+
+    my $images = $do->image_list();
+
+    for my $i (@{ $images->{content} }) {
+        say join "\t", $i->{distribution}, $i->{id}, $i->{name};
+    }
+
+More info: L<< https://developers.digitalocean.com/documentation/v2/#list-all-images >>.
 
 =head1 SEE ALSO
 
@@ -807,7 +823,7 @@ First DigitalOcean module, uses v1 API. It has a more OO
 approach than this module, and might have a more stable interface at the
 moment.
 
-=item L<< https://developers.digitalocean.com >>
+=item L<< https://developers.digitalocean.com/documentation/v2/ >>
 
 Documentation for API v2, in DigitalOcean's website.
 
