@@ -3,19 +3,20 @@ package WebService::DigitalOcean::Role::DropletActions;
 use utf8;
 use Moo::Role;
 use feature 'state';
-use Types::Standard qw/Str Enum Object Dict Int/;
+use Types::Standard qw/Str Enum Object Dict Int Bool/;
 use Type::Utils;
 use Type::Params qw/compile multisig/;
 
 requires 'make_request';
 
-our $VERSION = '0.023'; # VERSION
+our $VERSION = '0.024'; # VERSION
 
 sub droplet_resize {
     state $check = compile(
         Object,
         Dict[
             droplet => Int,
+            disk    => Bool,
             size    => Str,
         ],
     );
@@ -109,7 +110,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'reboot',
+            type    => 'reboot',
         });
     }
 
@@ -118,7 +119,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'power_cycle',
+            type    => 'power_cycle',
         });
     }
 
@@ -127,7 +128,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'power_on',
+            type    => 'power_on',
         });
     }
 
@@ -136,7 +137,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'power_off',
+            type    => 'power_off',
         });
     }
 
@@ -145,7 +146,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'password_reset',
+            type    => 'password_reset',
         });
     }
 
@@ -154,7 +155,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'shutdown',
+            type    => 'shutdown',
         });
     }
 
@@ -163,7 +164,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'enable_ipv6',
+            type    => 'enable_ipv6',
         });
     }
 
@@ -172,7 +173,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'enable_private_networking',
+            type    => 'enable_private_networking',
         });
     }
 
@@ -181,7 +182,7 @@ sub droplet_snapshot {
 
         return $self->_droplet_action_start({
             droplet => $id,
-            action  => 'disable_backups',
+            type    => 'disable_backups',
         });
     }
 }
@@ -222,7 +223,7 @@ WebService::DigitalOcean::Role::DropletActions - Droplet Actions role for Digita
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 DESCRIPTION
 
